<?php
/**
 * UAEL WPML compatibility.
 *
 * @package UAEL
 */

namespace UltimateElementor\Compatibility;

/**
 * Class UAEL_Wpml.
 */
class UAEL_Wpml {

	/**
	 * Member Variable
	 *
	 * @var instance
	 */
	private static $instance;

	/**
	 *  Initiator
	 */
	public static function get_instance() {
		if ( ! isset( self::$instance ) ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	/**
	 * Constructor
	 */
	public function __construct() {

		// WPML String Translation plugin exist check.
		if ( is_wpml_string_translation_active() ) {

			$this->includes();

			add_filter( 'wpml_elementor_widgets_to_translate', [ $this, 'translatable_widgets' ] );
		}
	}

	/**
	 * Integrations class for complex widgets.
	 *
	 * @since 1.2.0
	 */
	public function includes() {

		include_once( 'modules/buttons.php' );
		include_once( 'modules/table.php' );
		include_once( 'modules/google-map.php' );
		include_once( 'modules/price-list.php' );
		include_once( 'modules/business-hours.php' );
		include_once( 'modules/price-table.php' );
	}

	/**
	 * Widgets to translate.
	 *
	 * @since 1.2.0
	 * @param array $widgets Widget array.
	 * @return array
	 */
	function translatable_widgets( $widgets ) {

		$widgets['uael-advanced-heading'] = [
			'conditions' => [ 'widgetType' => 'uael-advanced-heading' ],
			'fields'     => [
				[
					'field'       => 'heading_title',
					'type'        => __( ' Advanced Heading : Heading', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'heading_description',
					'type'        => __( 'Advanced Heading : Description', 'uael' ),
					'editor_type' => 'AREA',
				],
			],
		];

		$widgets['uael-dual-color-heading'] = [
			'conditions' => [ 'widgetType' => 'uael-dual-color-heading' ],
			'fields'     => [
				[
					'field'       => 'before_heading_text',
					'type'        => __( 'Dual Color Heading : Before Text', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'second_heading_text',
					'type'        => __( 'Dual Color Heading : Highlighted Text', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'after_heading_text',
					'type'        => __( 'Dual Color Heading : After Text', 'uael' ),
					'editor_type' => 'LINE',
				],
			],
		];

		$widgets['uael-fancy-heading'] = [
			'conditions' => [ 'widgetType' => 'uael-fancy-heading' ],
			'fields'     => [
				[
					'field'       => 'fancytext_prefix',
					'type'        => __( 'Fancy Heading : Before Text', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'fancytext',
					'type'        => __( 'Fancy Heading : Fancy Text', 'uael' ),
					'editor_type' => 'AREA',
				],
				[
					'field'       => 'fancytext_suffix',
					'type'        => __( 'Fancy Heading : After Text', 'uael' ),
					'editor_type' => 'LINE',
				],
			],
		];

		$widgets['uael-ba-slider'] = [
			'conditions' => [ 'widgetType' => 'uael-ba-slider' ],
			'fields'     => [
				[
					'field'       => 'before_text',
					'type'        => __( 'Before After Slider : Before Label', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'after_text',
					'type'        => __( 'Before After Slider : After Label', 'uael' ),
					'editor_type' => 'LINE',
				],
			],
		];

		$widgets['uael-content-toggle'] = [
			'conditions' => [ 'widgetType' => 'uael-content-toggle' ],
			'fields'     => [
				[
					'field'       => 'rbs_section_heading_1',
					'type'        => __( 'Content Toggle : Heading 1', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'section_content_1',
					'type'        => __( 'Content Toggle : Description 1', 'uael' ),
					'editor_type' => 'VISUAL',
				],
				[
					'field'       => 'rbs_section_heading_2',
					'type'        => __( 'Content Toggle : Heading 2', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'section_content_2',
					'type'        => __( 'Content Toggle : Description 2', 'uael' ),
					'editor_type' => 'VISUAL',
				],
			],
		];

		$widgets['uael-modal-popup'] = [
			'conditions' => [ 'widgetType' => 'uael-modal-popup' ],
			'fields'     => [
				[
					'field'       => 'title',
					'type'        => __( 'Modal Popup : Modal Title', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'ct_content',
					'type'        => __( 'Modal Popup : Modal Description', 'uael' ),
					'editor_type' => 'VISUAL',
				],
				[
					'field'       => 'modal_text',
					'type'        => __( 'Modal Popup : Display on Text - Text', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'btn_text',
					'type'        => __( 'Modal Popup : Display on Button - Button Text', 'uael' ),
					'editor_type' => 'LINE',
				],
			],
		];

		$widgets['uael-infobox'] = [
			'conditions' => [ 'widgetType' => 'uael-infobox' ],
			'fields'     => [
				[
					'field'       => 'infobox_title_prefix',
					'type'        => __( 'Info Box : Title Prefix', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'infobox_title',
					'type'        => __( 'Info Box : Title', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'infobox_description',
					'type'        => __( 'Info Box : Description', 'uael' ),
					'editor_type' => 'VISUAL',
				],
				[
					'field'       => 'infobox_link_text',
					'type'        => __( 'Info Box : CTA Link Text', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'infobox_button_text',
					'type'        => __( 'Info Box : CTA Button Text', 'uael' ),
					'editor_type' => 'LINE',
				],
			],
		];

		$widgets['uael-buttons'] = [
			'conditions'        => [ 'widgetType' => 'uael-buttons' ],
			'fields'            => [],
			'integration-class' => '\UltimateElementor\Compatibility\WPML\Buttons',
		];

		$widgets['uael-table'] = [
			'conditions'        => [ 'widgetType' => 'uael-table' ],
			'fields'            => [],
			'integration-class' => '\UltimateElementor\Compatibility\WPML\Table',
		];

		$widgets['uael-google-map'] = [
			'conditions'        => [ 'widgetType' => 'uael-google-map' ],
			'fields'            => [],
			'integration-class' => '\UltimateElementor\Compatibility\WPML\GoogleMap',
		];

		$widgets['uael-price-list'] = [
			'conditions'        => [ 'widgetType' => 'uael-price-list' ],
			'fields'            => [],
			'integration-class' => '\UltimateElementor\Compatibility\WPML\PriceList',
		];

		$widgets['uael-price-table'] = [
			'conditions'        => [ 'widgetType' => 'uael-price-table' ],
			'fields'            => [
				[
					'field'       => 'heading',
					'type'        => __( 'Price Table : Title', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'sub_heading',
					'type'        => __( 'Price Table : Description', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'price',
					'type'        => __( 'Price Table : Price', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'original_price',
					'type'        => __( 'Price Table : Original Price', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'duration',
					'type'        => __( 'Price Table : Duration', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'sub_heading_style2',
					'type'        => __( 'Price Table : Description', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'cta_text',
					'type'        => __( 'Price Table : CTA Text', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'link',
					'type'        => __( 'Price Table : CTA Link', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'footer_additional_info',
					'type'        => __( 'Price Table : Disclaimer Text', 'uael' ),
					'editor_type' => 'LINE',
				],
				[
					'field'       => 'ribbon_title',
					'type'        => __( 'Price Table : Ribbon Title', 'uael' ),
					'editor_type' => 'LINE',
				],
			],
			'integration-class' => '\UltimateElementor\Compatibility\WPML\PriceTable',
		];

		$widgets['uael-business-hours'] = [
			'conditions'        => [ 'widgetType' => 'uael-business-hours' ],
			'fields'            => [],
			'integration-class' => '\UltimateElementor\Compatibility\WPML\BusinessHours',
		];

		$widgets['uael-image-gallery'] = [
			'conditions' => [ 'widgetType' => 'uael-image-gallery' ],
			'fields'     => [
				[
					'field'       => 'filters_all_text',
					'type'        => __( 'Image Galley : "All" Tab Label', 'uael' ),
					'editor_type' => 'LINE',
				],
			],
		];

		$widgets['uael-woo-add-to-cart'] = [
			'conditions' => [ 'widgetType' => 'uael-woo-add-to-cart' ],
			'fields'     => [
				[
					'field'       => 'btn_text',
					'type'        => __( 'Woo - Add To Cart : Text', 'uael' ),
					'editor_type' => 'LINE',
				],
			],
		];

		return $widgets;
	}
}

/**
 *  Prepare if class 'UAEL_Wpml' exist.
 *  Kicking this off by calling 'get_instance()' method
 */
UAEL_Wpml::get_instance();
